@@ -1,7 +1,9 @@
 from ._session import DynamoDbSession, DynamoDbSessionInstance, FlaskNullSessionInstance
+from . import testing
 
 __all__ = [
     'DynamoDbSession',
     'DynamoDbSessionInstance',
     'FlaskNullSessionInstance',
+    'testing',
 ]
